@@ -1,4 +1,4 @@
-gsd.drift <- function(ifrac, sig.level = 0.05, pow = 0.8, delta.eb = 0.5, delta.fb = 0, alternative = c("two.sided", "one.sided"), tol=0.001) {
+gsd.drift <- function(ifrac, sig.level = 0.05, pow = 0.8, delta.eb = 0.5, delta.fb = 0, alternative = c("two.sided", "one.sided"), tol=0.0001) {
   alternative <- match.arg(alternative)
   nlook <- length(ifrac)
 # The statistics are standardized Brownian motion in [0,1] time interval
@@ -102,34 +102,65 @@ gsd.drift <- function(ifrac, sig.level = 0.05, pow = 0.8, delta.eb = 0.5, delta.
 
 gsdesign.binomial <- function(ifrac, pC, pE, sig.level=0.05, power=0.8,
                               delta.eb = 0.5, delta.fb = 0, alternative =
-                              c("two.sided", "one.sided"), tol=0.001) {
-  drift.out <- gsd.drift(ifrac, sig.level, power, delta.eb, delta.fb, alternative)
+                              c("two.sided", "one.sided"), tol=0.0001) {
+  drift.out <- gsd.drift(ifrac, sig.level, power, delta.eb, delta.fb, alternative, tol)
   pbar <- (pC+pE)/2
   n <- 2*pbar*(1-pbar)*(drift.out$drift/(pC-pE))^2
   out <- drift.out
   out$drift <- NULL
+  out$pC <- pC
+  out$pE <- pE
+  out$outcome <- "binary"
   out$sample.size <- n
+  class(out) <- "gsdesign"
   out
 }
 
 gsdesign.normal <- function(ifrac, delta, sd=1, sig.level=0.05, power=0.8,
                             delta.eb = 0.5, delta.fb = 0, alternative =
-                            c("two.sided", "one.sided"), tol=0.001) {
-  drift.out <- gsd.drift(ifrac, sig.level, power, delta.eb, delta.fb, alternative)
+                            c("two.sided", "one.sided"), tol=0.0001) {
+  drift.out <- gsd.drift(ifrac, sig.level, power, delta.eb, delta.fb, alternative, tol)
   n <- 2*(drift.out$drift*sd/delta)^2
   out <- drift.out
   out$drift <- NULL
+  out$delta <- delta
+  out$sd <- sd
+  out$outcome <- "normal"
   out$sample.size <- n
+  class(out) <- "gsdesign"
   out
 }
 
 gsdesign.survival <- function(ifrac, haz.ratio, sig.level = 0.05, power = 0.8,
                               delta.eb = 0.5, delta.fb = 0, alternative = 
-                              c("two.sided", "one.sided"), tol=0.001) {
-  drift.out <- gsd.drift(ifrac, sig.level, power, delta.eb, delta.fb, alternative)
+                              c("two.sided", "one.sided"), tol=0.0001) {
+  drift.out <- gsd.drift(ifrac, sig.level, power, delta.eb, delta.fb, alternative, tol)
   d <- 4*(drift.out$drift/log(haz.ratio))^2
   out <- drift.out
   out$drift <- NULL
+  out$haz.ratio <- haz.ratio
+  out$outcome <- "survival"
   out$num.events <- d
+  class(out) <- "gsdesign"
   out
 }
+
+print.gsdesign <- function(x, ...) {
+  if (class(x) != "gsdesign") stop("input shoud be a gsdesign class object")
+  cat("\n Group sequential design for comparing", x$outcome, "data with ")
+  switch(match(x$outcome, c("binary", "normal", "survival")),
+         cat("rates  pC =", x$p1,", pE =", x$p2, "\n\n"),
+         cat("delta =", x$delta, ", sd =", x$sd, "\n\n"),
+         cat("hazard ratio =", x$haz.ratio, "\n\n"))
+  switch(match(x$outcome, c("binary", "normal", "survival")),
+         cat("  sample size (per arm) =", x$sample.size, "\n"),
+         cat("  sample size (per arm) =", x$sample.size, "\n"),
+         cat(" total number of events =", x$num.events, "\n"))
+  cat("   information fraction =", format(round(x$ifrac, 3), digits=3), "\n")
+  cat("          boundary type =", x$delta.eb, " (Pocock = 0; O'Brien-Fleming = 0.5) \n")
+  cat("      efficacy boundary =", round(x$efbdry, 3), "\n")
+  cat("              sig.level =", x$sig.level, "\n")
+  cat("                  power =", x$power, "\n")
+  cat("            alternative =", x$alternative, "\n\n")
+  invisible(x)
+}
